@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 #-----------------------------------------------------------------------------
-# Copyright (c) 2018-2020, NeXpy Development Team.
+# Copyright (c) 2018-2021, NeXpy Development Team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -12,19 +12,19 @@
 """
 This module contains a set of customized widgets both for dialogs and plot objects. 
 """
+import math
 import warnings
 
-import matplotlib as mpl
-import math
 import numpy as np
-from matplotlib import colors
-from matplotlib import cbook
-from matplotlib.patches import Circle, Ellipse, Polygon, Rectangle
 
 from .pyqt import QtCore, QtGui, QtWidgets
-from .utils import (report_error, boundaries, get_color, format_float,
-                    find_nearest, natural_sort)
 
+import matplotlib as mpl
+from matplotlib import cbook, colors
+from matplotlib.patches import Circle, Ellipse, Polygon, Rectangle
+
+from .utils import (boundaries, find_nearest, format_float, get_color,
+                    natural_sort, report_error)
 
 warnings.filterwarnings("ignore", category=cbook.mplDeprecation)
 
@@ -187,8 +187,8 @@ class NXLineEdit(QtWidgets.QLineEdit):
     after any programmatic changes.
     """
 
-    def __init__(self, text=None, parent=None, slot=None, width=None, 
-                 align='left'):
+    def __init__(self, text=None, parent=None, slot=None, readonly=False,
+                 width=None, align='left'):
         """Initialize the edit window and optionally set the alignment
         
         Parameters
@@ -207,6 +207,8 @@ class NXLineEdit(QtWidgets.QLineEdit):
             self.editingFinished.connect(slot)
         if text is not None:
             self.setText(text)
+        if readonly:
+            self.setReadOnly(True)
         if width:
             self.setFixedWidth(width)
         if align == 'left':
@@ -621,8 +623,7 @@ class NXColorBox(QtWidgets.QWidget):
         if label:
             self.layout.addStretch()
             self.layout.addWidget(NXLabel(label))
-        self.textbox = NXLineEdit(colors.to_hex(color.getRgbF(),
-                                                keep_alpha=True),
+        self.textbox = NXLineEdit(colors.to_hex(color.getRgbF()),
                                   parent=parent, slot=self.update_color, 
                                   width=width, align='right')
         self.layout.addWidget(self.textbox)
@@ -646,7 +647,7 @@ class NXColorBox(QtWidgets.QWidget):
 
     def update_text(self, color):
         """Set the text box string following a change to the color button."""
-        self.color_text = colors.to_hex(color.getRgbF(), keep_alpha=True)
+        self.color_text = colors.to_hex(color.getRgbF())
         self.textbox.setText(self.color_text)
 
     def qcolor(self, text):
